# Ultrafast-ARPES

Ultrfast-ARPES, Tr-ARPES/TARPES, or pump-probe ARPES refers to pump probe photoemission 
experiments conducted with pulses from a laser typically of femtosecond duration. Some pump 
probe modalities nonetheless exist at synchrotrons, and CW experiments can indirectly access 
dynamics by measuring quasiparticle diffusion.

Tr-ARPES datasets can in principle have at least two additional degrees of freedom, the excitation 
delay&mdash;referred to through PyARPES as `delay`&mdash;and the pump wavelength.

Analysis tools for Tr-ARPES exist in `arpes.analysis.tarpes`. Plotting utilities are to be found in
`arpes.plotting.tarpes`.

More details and analysis examples to come in the future. 